Plugins
=======

Plugin stages
-------------

* Plugin constuctor
* Plugin.shutdown
* Plugin.init_instance
* Plugin.deactivate_instance
TODO: Describe this ;-)


Adding UI elements
------------------

* TODO: Describe adding actions and instance.ui.add_ui_from_string
* TODO: Describe named placeholders in mainwin's UI description

.. autoclass:: cf.plugins.Plugin
   :members:

.. autoclass:: cf.plugins.ExportPlugin
   :members:
